summaryrefslogtreecommitdiff
path: root/actions/profilesettings.php
diff options
context:
space:
mode:
authorEvan Prodromou <evan@status.net>2009-08-27 11:16:45 -0700
committerEvan Prodromou <evan@status.net>2009-08-27 11:16:45 -0700
commit5d09b6b3f0595540c66b703ae085f0af904fe30f (patch)
tree59269a4dacf90bbab9f0ff63afff4bf1781a1240 /actions/profilesettings.php
parentf1fda6c0503e32edfc99b297f4bf2cb07e629d9e (diff)
parent82b0927f5838f3c12816e03712df9460a9f77b72 (diff)
Merge branch '0.8.x' into 0.9.x
Conflicts: EVENTS.txt actions/finishremotesubscribe.php actions/postnotice.php actions/public.php actions/remotesubscribe.php actions/showstream.php actions/updateprofile.php actions/userauthorization.php classes/laconica.ini lib/common.php lib/oauthstore.php lib/omb.php
Diffstat (limited to 'actions/profilesettings.php')
-rw-r--r--actions/profilesettings.php22
1 files changed, 11 insertions, 11 deletions
diff --git a/actions/profilesettings.php b/actions/profilesettings.php
index f429a2e51..83051c6fd 100644
--- a/actions/profilesettings.php
+++ b/actions/profilesettings.php
@@ -1,6 +1,6 @@
<?php
/**
* Laconica, the distributed open-source microblogging tool
*
* Change profile settings
*
@@ -20,15 +20,15 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
* @category Settings
- * @package Laconica
- * @author Evan Prodromou <evan@controlyourself.ca>
- * @author Zach Copley <zach@controlyourself.ca>
- * @copyright 2008-2009 Control Yourself, Inc.
+ * @package StatusNet
+ * @author Evan Prodromou <evan@status.net>
+ * @author Zach Copley <zach@status.net>
+ * @copyright 2008-2009 StatusNet, Inc.
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*/
-if (!defined('LACONICA')) {
+if (!defined('STATUSNET') && !defined('LACONICA')) {
exit(1);
}
@@ -38,11 +38,11 @@ require_once INSTALLDIR.'/lib/accountsettingsaction.php';
* Change profile settings
*
* @category Settings
- * @package Laconica
- * @author Evan Prodromou <evan@controlyourself.ca>
- * @author Zach Copley <zach@controlyourself.ca>
+ * @package StatusNet
+ * @author Evan Prodromou <evan@status.net>
+ * @author Zach Copley <zach@status.net>
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*/
class ProfilesettingsAction extends AccountSettingsAction
@@ -1,6 +1,6 @@
<?php
/**
- * Laconica, the distributed open-source microblogging tool
+ * StatusNet, the distributed open-source microblogging tool
*
* Change profile settings